<?php

declare(strict_types=1);

namespace Drupal\tab_title_attention\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Configure Tab Title Attention settings for this site.
 */
final class SettingsForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId(): string {
    return 'tab_title_attention_settings';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames(): array {
    return ['tab_title_attention.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state): array {
    $form['active'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Active'),
      '#description' => $this->t("Check to enable the module's functionality."),
      '#default_value' => $this->config('tab_title_attention.settings')->get('active'),
    ];
    $form['delay'] = [
      '#type' => 'number',
      '#min' => 0,
      '#step' => 1,
      '#field_suffix' => $this->t('ms'),
      '#title' => $this->t('Animation delay'),
      '#description' => $this->t('The delay before the animation starts, after the tab loses focus.'),
      '#default_value' => $this->config('tab_title_attention.settings')->get('delay'),
    ];
    $form['message'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Title message'),
      '#description' => $this->t('The message that will appear in the tab title, after it loses focus.'),
      '#default_value' => $this->config('tab_title_attention.settings')->get('message'),
    ];
    $form['animation'] = [
      '#type' => 'radios',
      '#options' => [
        'static' => $this->t('Static'),
        'blink' => $this->t('Blinking (with previous title)'),
        'blink_empty' => $this->t('Blinking (with empty title)'),
        'scroll' => $this->t('Scrolling'),
      ],
      '#required' => TRUE,
      '#title' => $this->t('Animation type'),
      '#description' => $this->t('The type of animation that the title message will play.'),
      '#default_value' => $this->config('tab_title_attention.settings')->get('animation'),
    ];
    $form['animation']['static']['#description'] = $this->t('The message will replace the tab title without any animation.');
    $form['animation']['blink']['#description'] = $this->t('The tab title will blink, switching between the message and the previous tab title.');
    $form['animation']['blink_empty']['#description'] = $this->t('The tab title will blink, switching between the message and an empty title.');
    $form['animation']['scroll']['#description'] = $this->t('The message will appear and scroll through repeatedly from right to left (similar to a marquee).');
    $form['speed'] = [
      '#type' => 'number',
      '#min' => 0,
      '#step' => 1,
      '#field_suffix' => $this->t('ms'),
      '#title' => $this->t('Animation speed'),
      '#description' => $this->t('The speed of the animation (does not apply to "Static").<br><em>Note that some browsers might automatically limit the animation speed for inactive tabs.</em>'),
      '#default_value' => $this->config('tab_title_attention.settings')->get('speed'),
    ];
    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state): void {
    $this->config('tab_title_attention.settings')
      ->set('active', $form_state->getValue('active'))
      ->set('delay', $form_state->getValue('delay'))
      ->set('message', $form_state->getValue('message'))
      ->set('animation', $form_state->getValue('animation'))
      ->set('speed', $form_state->getValue('speed'))
      ->save();
    parent::submitForm($form, $form_state);
  }

}
